DataflowLayout

Struct DataflowLayout 

pub struct DataflowLayout {
    pub inputs: HashSet<Uuid>,
    pub outputs: HashSet<Uuid>,
    pub queries: HashSet<Uuid>,
    pub queryables: HashSet<Uuid>,
    pub labels: HashMap<Uuid, String>,
    pub nodes: HashMap<Uuid, HashSet<Uuid>>,
}
Represents a flattened dataflow layout

Fields

inputs: HashSet<Uuid>

Inputs present in the dataflow

outputs: HashSet<Uuid>

Outputs present in the dataflow

queries: HashSet<Uuid>

Queries present in the dataflow

queryables: HashSet<Uuid>

Queryables present in the dataflow

labels: HashMap<Uuid, String>

Labels for nodes and IO, useful for debugging and visualization

nodes: HashMap<Uuid, HashSet<Uuid>>

Nodes representation with their IO, useful for debugging and visualization

Implementations

Source

impl DataflowLayout

pub fn new() -> DataflowLayout

Creates a new empty dataflow layout

Examples found in repository?
examples/service_flows.rs (line 5)
4async fn main() -> Result<()> {
5    let mut layout = DataflowLayout::new();
6
7    let (_service, queryable) = layout
8        .node("service", async |builder: &mut NodeIOBuilder| {
9            builder.queryable("queryable")
10        })
11        .await;
12
13    let (_client, query) = layout
14        .node("client", async |builder: &mut NodeIOBuilder| {
15            builder.query("query")
16        })
17        .await;
18
19    let layout = layout.build();
20
21    let _flows = Flows::new(layout.clone(), async move |builder: &mut FlowsBuilder| {
22        builder.connect(query, queryable, None)?;
23
24        Ok(())
25    })
26    .await?;
27
28    Ok(())
29}
More examples
Hide additional examples
examples/simple_flows.rs (line 5)
4async fn main() -> Result<()> {
5    let mut layout = DataflowLayout::new();
6
7    let (_source, output) = layout
8        .node("source", async |builder: &mut NodeIOBuilder| {
9            builder.output("out")
10        })
11        .await;
12
13    let (_operator, (op_in, op_out)) = layout
14        .node("operator", async |builder: &mut NodeIOBuilder| {
15            (builder.input("in"), builder.output("out"))
16        })
17        .await;
18
19    let (_sink, input) = layout
20        .node("sink", async |builder: &mut NodeIOBuilder| {
21            builder.input("in")
22        })
23        .await;
24
25    let layout = layout.build();
26
27    let _flows = Flows::new(layout.clone(), async move |builder: &mut FlowsBuilder| {
28        builder.connect(op_in, output, None)?;
29        builder.connect(input, op_out, None)?;
30
31        Ok(())
32    })
33    .await?;
34
35    Ok(())
36}
pub async fn node<T>( &mut self, label: impl Into<String>, builder_function: impl AsyncFnOnce(&mut NodeIOBuilder) -> T, ) -> (NodeLayout, T)

Adds a new node to the dataflow layout, providing its label and a builder function for its IO. For convenience, the node layout is returned, together with the result of the builder function.

Examples found in repository?
examples/service_flows.rs (lines 8-10)
4async fn main() -> Result<()> {
5    let mut layout = DataflowLayout::new();
6
7    let (_service, queryable) = layout
8        .node("service", async |builder: &mut NodeIOBuilder| {
9            builder.queryable("queryable")
10        })
11        .await;
12
13    let (_client, query) = layout
14        .node("client", async |builder: &mut NodeIOBuilder| {
15            builder.query("query")
16        })
17        .await;
18
19    let layout = layout.build();
20
21    let _flows = Flows::new(layout.clone(), async move |builder: &mut FlowsBuilder| {
22        builder.connect(query, queryable, None)?;
23
24        Ok(())
25    })
26    .await?;
27
28    Ok(())
29}
More examples
Hide additional examples
examples/simple_flows.rs (lines 8-10)
4async fn main() -> Result<()> {
5    let mut layout = DataflowLayout::new();
6
7    let (_source, output) = layout
8        .node("source", async |builder: &mut NodeIOBuilder| {
9            builder.output("out")
10        })
11        .await;
12
13    let (_operator, (op_in, op_out)) = layout
14        .node("operator", async |builder: &mut NodeIOBuilder| {
15            (builder.input("in"), builder.output("out"))
16        })
17        .await;
18
19    let (_sink, input) = layout
20        .node("sink", async |builder: &mut NodeIOBuilder| {
21            builder.input("in")
22        })
23        .await;
24
25    let layout = layout.build();
26
27    let _flows = Flows::new(layout.clone(), async move |builder: &mut FlowsBuilder| {
28        builder.connect(op_in, output, None)?;
29        builder.connect(input, op_out, None)?;
30
31        Ok(())
32    })
33    .await?;
34
35    Ok(())
36}
pub fn label(&self, uuid: impl Into<Uuid>) -> String

Access the label of an entity in the dataflow layout (node, input, output, query, queryable)

pub fn build(self) -> Arc<DataflowLayout>

Build the dataflow layout by making it immutable and returning an Arc

Examples found in repository?
examples/service_flows.rs (line 19)
4async fn main() -> Result<()> {
5    let mut layout = DataflowLayout::new();
6
7    let (_service, queryable) = layout
8        .node("service", async |builder: &mut NodeIOBuilder| {
9            builder.queryable("queryable")
10        })
11        .await;
12
13    let (_client, query) = layout
14        .node("client", async |builder: &mut NodeIOBuilder| {
15            builder.query("query")
16        })
17        .await;
18
19    let layout = layout.build();
20
21    let _flows = Flows::new(layout.clone(), async move |builder: &mut FlowsBuilder| {
22        builder.connect(query, queryable, None)?;
23
24        Ok(())
25    })
26    .await?;
27
28    Ok(())
29}
More examples
Hide additional examples
examples/simple_flows.rs (line 25)
4async fn main() -> Result<()> {
5    let mut layout = DataflowLayout::new();
6
7    let (_source, output) = layout
8        .node("source", async |builder: &mut NodeIOBuilder| {
9            builder.output("out")
10        })
11        .await;
12
13    let (_operator, (op_in, op_out)) = layout
14        .node("operator", async |builder: &mut NodeIOBuilder| {
15            (builder.input("in"), builder.output("out"))
16        })
17        .await;
18
19    let (_sink, input) = layout
20        .node("sink", async |builder: &mut NodeIOBuilder| {
21            builder.input("in")
22        })
23        .await;
24
25    let layout = layout.build();
26
27    let _flows = Flows::new(layout.clone(), async move |builder: &mut FlowsBuilder| {
28        builder.connect(op_in, output, None)?;
29        builder.connect(input, op_out, None)?;
30
31        Ok(())
32    })
33    .await?;
34
35    Ok(())
36}