Flows

Struct Flows 

pub struct Flows {
    pub inputs_receivers: Arc<Mutex<HashMap<Uuid, MessageReceiver>>>,
    pub outputs_senders: Arc<Mutex<HashMap<Uuid, Vec<MessageSender>>>>,
    pub queries_senders: Arc<Mutex<HashMap<Uuid, MessageSender>>>,
    pub queries_receivers: Arc<Mutex<HashMap<Uuid, MessageReceiver>>>,
    pub queryables_senders: Arc<Mutex<HashMap<Uuid, HashMap<Uuid, MessageSender>>>>,
    pub queryables_receivers: Arc<Mutex<HashMap<Uuid, MessageReceiver>>>,
}
Represents the collection of flows in the system (all the MPSC channels)

Fields

inputs_receivers: Arc<Mutex<HashMap<Uuid, MessageReceiver>>>outputs_senders: Arc<Mutex<HashMap<Uuid, Vec<MessageSender>>>>queries_senders: Arc<Mutex<HashMap<Uuid, MessageSender>>>queries_receivers: Arc<Mutex<HashMap<Uuid, MessageReceiver>>>queryables_senders: Arc<Mutex<HashMap<Uuid, HashMap<Uuid, MessageSender>>>>queryables_receivers: Arc<Mutex<HashMap<Uuid, MessageReceiver>>>

Implementations

Source

impl Flows

pub async fn new( layout: Arc<DataflowLayout>, flows: impl AsyncFnOnce(&mut FlowsBuilder) -> Result<()>, ) -> Result<Self>

Creates a new Flows instance with a Building async closure

Examples found in repository?
examples/service_flows.rs (lines 21-25)
4async fn main() -> Result<()> {
5    let mut layout = DataflowLayout::new();
6
7    let (_service, queryable) = layout
8        .node("service", async |builder: &mut NodeIOBuilder| {
9            builder.queryable("queryable")
10        })
11        .await;
12
13    let (_client, query) = layout
14        .node("client", async |builder: &mut NodeIOBuilder| {
15            builder.query("query")
16        })
17        .await;
18
19    let layout = layout.build();
20
21    let _flows = Flows::new(layout.clone(), async move |builder: &mut FlowsBuilder| {
22        builder.connect(query, queryable, None)?;
23
24        Ok(())
25    })
26    .await?;
27
28    Ok(())
29}
More examples
Hide additional examples
examples/simple_flows.rs (lines 27-32)
4async fn main() -> Result<()> {
5    let mut layout = DataflowLayout::new();
6
7    let (_source, output) = layout
8        .node("source", async |builder: &mut NodeIOBuilder| {
9            builder.output("out")
10        })
11        .await;
12
13    let (_operator, (op_in, op_out)) = layout
14        .node("operator", async |builder: &mut NodeIOBuilder| {
15            (builder.input("in"), builder.output("out"))
16        })
17        .await;
18
19    let (_sink, input) = layout
20        .node("sink", async |builder: &mut NodeIOBuilder| {
21            builder.input("in")
22        })
23        .await;
24
25    let layout = layout.build();
26
27    let _flows = Flows::new(layout.clone(), async move |builder: &mut FlowsBuilder| {
28        builder.connect(op_in, output, None)?;
29        builder.connect(input, op_out, None)?;
30
31        Ok(())
32    })
33    .await?;
34
35    Ok(())
36}
pub fn node_io( &self, clock: Arc<HLC>, source: NodeLayout, ) -> (Inputs, Outputs, Queries, Queryables)

This is intended to be used only by the Runtime when loading nodes